@@ -1,9 +1,6 @@
 import sys as _sys
 from importlib import import_module as _import_module
-from importlib.abc import Loader as _Loader
-from importlib.abc import MetaPathFinder as _MetaPathFinder
 
-from . import mask  # noqa
 from ._version import get_versions
 
 
@@ -59,9 +56,11 @@ _SPECIAL_ATTRS = {
     "expr",
     "ffi",
     "formatting",
+    "indexunary",
     "infix",
     "io",
     "lib",
+    "mask",
     "matrix",
     "monoid",
     "op",
@@ -75,6 +74,7 @@ _SPECIAL_ATTRS = {
     "unary",
     "utils",
     "vector",
+    "viz",
 }
 
 
@@ -84,7 +84,10 @@ def __getattr__(name):
         if _init_params is None:
             _init("suitesparse", None, automatic=True)
         if name not in globals():
-            _load(name)
+            if f"graphblas.{name}" in _sys.modules:
+                globals()[name] = _sys.modules[f"graphblas.{name}"]
+            else:
+                _load(name)
         return globals()[name]
     else:
         raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
@@ -146,25 +149,14 @@ def _init(backend_arg, blocking, automatic=False):
             if blocking is None:
                 blocking = False
                 passed_params["blocking"] = blocking
-            for attr in dir(lib):
-                getattr(lib, attr)
             initialize(blocking=blocking, memory_manager="numpy")
     else:
         raise ValueError(f'Bad backend name.  Must be "suitesparse".  Got: {backend}')
     _init_params = passed_params
 
 
-_NEEDS_OPERATOR = {
-    "graphblas._agg",
-    "graphblas.agg",
-    "graphblas.base",
-    "graphblas.io",
-    "graphblas.matrix",
-    "graphblas.scalar",
-    "graphblas.vector",
-    "graphblas.recorder",
-    "graphblas.ss",
-}
+# Ideally this is in operator.py, but lives here to avoid circular references
+_STANDARD_OPERATOR_NAMES = set()
 
 
 def _load(name):
@@ -173,42 +165,12 @@ def _load(name):
         if module_name not in globals():
             _load(module_name)
         module = globals()[module_name]
-        val = getattr(module, name)
-        globals()[name] = val
+        globals()[name] = getattr(module, name)
     else:
         # Everything else is a module
-        module = _import_module(f".{name}", __name__)
-        globals()[name] = module
+        globals()[name] = _import_module(f".{name}", __name__)
 
 
-class _GraphblasModuleFinder(_MetaPathFinder):
-    def find_spec(self, fullname, path, target=None):
-        if fullname in _NEEDS_OPERATOR and "operator" not in globals():
-            _load("operator")
-            name = fullname[7:]  # Trim "graphblas."
-            if name in globals():  # pragma: no cover
-                # Make sure we execute the module only once
-                module = globals()[name]
-                spec = module.__spec__
-                spec.loader = _SkipLoad(module, spec.loader)
-                return spec
-
-
-class _SkipLoad(_Loader):
-    def __init__(self, module, orig_loader):  # pragma: no cover
-        self.module = module
-        self.orig_loader = orig_loader
-
-    def create_module(self, spec):  # pragma: no cover
-        return self.module
-
-    def exec_module(self, module):  # pragma: no cover
-        # Don't execute the module, but restore the original loader
-        module.__spec__.loader = self.orig_loader
-
-
-_sys.meta_path.insert(0, _GraphblasModuleFinder())
-
 __version__ = get_versions()["version"]
 del get_versions
 
