@@ -15,16 +15,16 @@ def pytest_configure(config):
     randomly = config.getoption("--randomly", False)
     backend = config.getoption("--backend", "suitesparse")
     blocking = config.getoption("--blocking", True)
-    if blocking is None:
+    if blocking is None:  # pragma: no branch
         blocking = np.random.rand() < 0.5 if randomly else True
     record = config.getoption("--record", False)
-    if record is None:
+    if record is None:  # pragma: no branch
         record = np.random.rand() < 0.5 if randomly else False
     mapnumpy = config.getoption("--mapnumpy", False)
-    if mapnumpy is None:
+    if mapnumpy is None:  # pragma: no branch
         mapnumpy = np.random.rand() < 0.5 if randomly else False
     runslow = config.getoption("--runslow", False)
-    if runslow is None:
+    if runslow is None:  # pragma: no branch
         runslow = np.random.rand() < 0.25 if randomly else False
     config.runslow = runslow
 
