@@ -4,7 +4,7 @@ import pytest
 from graphblas import binary, dtypes, replace, unary
 from graphblas.expr import Updater
 
-from graphblas import Matrix, Scalar, Vector  # isort:skip
+from graphblas import Matrix, Scalar, Vector  # isort:skip (for dask-graphblas)
 
 
 def test_from_values_dtype_resolving():
